#
# spec file for package octave-forge-geometry
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define octpkg  geometry
Name:           octave-forge-%{octpkg}
Version:        4.0.0
Release:        2.4
Summary:        Computational Geometry for Octave
License:        GPL-3.0-or-later AND BSD-2-Clause
Group:          Productivity/Scientific/Math
URL:            https://octave.sourceforge.io/%{octpkg}/index.html
Source0:        https://downloads.sourceforge.net/octave/%{octpkg}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM
Patch0:         compile-with-g++-v11.patch
BuildRequires:  octave-devel >= 4.2.0
Requires:       octave-cli >= 4.0.1
Requires:       octave-forge-matgeom >= 1.0.0

%description
Library for geometric computing extending MatGeom functions.
Useful to create, transform, manipulate and display geometric
primitives.
This is part of Octave-Forge project.

%prep
%setup -q -c %{name}-%{version}
pushd %{octpkg}-%{version}
%patch0 -p1
popd
%octave_pkg_src

%build
%octave_pkg_build

%install
%octave_pkg_install

%check
%octave_pkg_test

%post
%octave --eval "pkg rebuild"

%postun
%octave --eval "pkg rebuild"

%files
%defattr(-,root,root)
%{octpackages_dir}/%{octpkg}-%{version}
%{octlib_dir}/%{octpkg}-%{version}

%changelog
* Fri Jul  9 2021 Christophe Giboudeaux <christophe@krop.fr>
- Add upstream patch:
  * compile-with-g++-v11.patch
* Thu Feb 20 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 4.0.0
  * As of this version, geometry does not contain any matgeom
    functionality. It contains all the extra functions that we
    have been adding to geometry, in particular matlab compatible
    functionality for the mapping package.
    It might need that you do not need geometry anymore and
    instead you need to install matgeom to get the functionality
    you were using.
  * Functions have been modified
    clipPolygon:
  - Accepts boolean operation as strings or as integer.
  - Accepts a box [xmin xmax ymin ymax] as clipping polygon.
  * Added Functions
    drawFilledPolygon
* Wed Nov 27 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 3.0.0
  * This version of the package is not backward compatible for the
    following reasons:
    +  Functions have changed their name
  beltproblem      --> beltProblem
  closed_path      --> closedPath
  shapearea        --> shapeArea
  shapecentroid    --> shapeCentroid
  shapeplot        --> plotShape
  shapetransform   --> transformShape
    simplifypolygon  --> simplifyPoligon
    simplifyPolyline --> simplifyPolyline
    + Functions that are in GNU Octave core since 4.0.1
  rad2deg deg2rad
  * Added Functions:
    isAxisHandle isPolygonCCW isPolygonCW_Clipper joinPolygons polygon2patch
    orientPolygon boundedVoronoi2d drawGraphEdges clipGraph grAdjacentEdges
    grAdjacentNodes grEdgeLengths centroidalVoronoi2d clipGraphPolygon
    cvtUpdate intersectEdgePolygon intersectLinePolygon isPointInPolygon
    polygonBounds polygonContains convexHull minimumCaliperDiameter
    grShortestPath drawNodeLabels nndist createRotation3dLineAngle drawPlane3d
    rotation3dAxisAndAngle boxToMesh checkMeshAdjacentFaces
    clipConvexPolyhedronHP clipMeshVertices createDodecahedron
    createDurerPolyhedron createIcosahedron createMengerSponge createOctahedron
    createRhombododecahedron createSoccerBall createTetrahedron
    createTetrakaidecahedron cylinderMesh drawFaceNormals drawPolyhedron
    ellipsoidMesh faceCentroids faceNormal intersectLineMesh3d intersectPlaneMesh
    mergeCoplanarFaces meshAdjacencyMatrix meshDihedralAngles meshEdgeFaces
    meshEdgeLength meshEdges meshFace meshFaceAdjacency meshFaceEdges
    meshFaceNumber meshFacePolygons meshSurfaceArea meshVolume minConvexHull
    polyhedra polyhedronCentroid polyhedronMeanBreadth polyhedronNormalAngle
    polyhedronSlice readMesh_off removeMeshVertices smoothMesh sphereMesh
    steinerPolytope subdivideMesh surfToMesh tetrahedronVolume torusMesh
    triangulateFaces trimMesh trimeshEdgeFaces trimeshMeanBreadth
    trimeshSurfaceArea vertexNormal distancePoints clipLine3d
    drawLine3d eulerAnglesToRotation3d intersectLineSphere linePosition3d
    recenterTransform3d transformLine3d transformVector3d intersectPolylines
    clipPolyline clipPolyline_clipper clipPolygon clipPolygon_clipper
  * Improved Functions
    + drawPolygon is more efficent when drawing polygons in cells and now it
    takes an axis handle as first argument (optional). Added demo and tests
    + intersectEdges accepts tolerance as third argument
    + polygon2patch demo fixed, missing third argument for patch.
* Fri Jun 10 2016 dmitry_r@opensuse.org
- Update to version 2.1.1
  * Added Functions:
    'projPointOnPolyline': the function is added for compatibility,
    but it is just a wrapper of distancePointPolyline.
    'findClosestPoint'
    'fillPolygon'
    'rectAsPolygon'
  * Improved Functions
    'distancePointPolyline' is now updated with a spee dup of 100x.
    It also calculates the projections.
* Sat May  2 2015 dmitry_r@opensuse.org
- Update to version 2.0.0
  * Geometry 2.0.0 is not compatible with versions of octave older
    than 4.0. Thi si due to inputParser being used in the functions
    curve2polyline, cov2ellipse and simplifypolyline. If you do not
    need this functions you should no problems using octave > 3.6.0
  * Removed functions: oc_polybol is not part of geomtry anymore.
    This function is part of the octclip package.
  * Added Functions: planePoint
  * Drop obsolete geometry-openmp.patch
* Thu Feb 26 2015 dmitry_r@opensuse.org
- Split from octave-forge package, version 1.7.0
- Fix build with openmp
  * geometry-openmp.patch
